package com.ygtx.gxt.service;

import java.util.List;
import com.ygtx.gxt.domain.GxtUserFanInspectionScore;

/**
 * 维保风机类型检查得分Service接口
 * 
 * @author ruoyi
 * @date 2025-11-06
 */
public interface IGxtUserFanInspectionScoreService 
{
    /**
     * 查询维保风机类型检查得分
     * 
     * @param id 维保风机类型检查得分主键
     * @return 维保风机类型检查得分
     */
    public GxtUserFanInspectionScore selectGxtUserFanInspectionScoreById(Long id);

    /**
     * 查询维保风机类型检查得分列表
     * 
     * @param gxtUserFanInspectionScore 维保风机类型检查得分
     * @return 维保风机类型检查得分集合
     */
    public List<GxtUserFanInspectionScore> selectGxtUserFanInspectionScoreList(GxtUserFanInspectionScore gxtUserFanInspectionScore);

    /**
     * 查询当月维保机组类型评分
     * 
     * @return 维保风机类型检查得分集合
     */
    public List<GxtUserFanInspectionScore> selectFanInspectionScoreForCurrentMonth();

    /**
     * 根据条件查询维保机组类型评分
     * 
     * @param rtType 实时类型
     * @param monthPeriod 统计月份
     * @param userId 用户ID
     * @param deptId 部门ID
     * @return 维保风机类型检查得分集合
     */
    public List<GxtUserFanInspectionScore> selectFanInspectionScoreByCondition(Integer rtType, String monthPeriod, Long userId, Long deptId, String permission);

    public List<GxtUserFanInspectionScore> selectFanInspectionScoreByDeptId(Integer rtType, String monthPeriod, Long userId, Long deptId, String permission);

    /**
     * 新增维保风机类型检查得分
     * 
     * @param gxtUserFanInspectionScore 维保风机类型检查得分
     * @return 结果
     */
    public int insertGxtUserFanInspectionScore(GxtUserFanInspectionScore gxtUserFanInspectionScore);

    /**
     * 修改维保风机类型检查得分
     * 
     * @param gxtUserFanInspectionScore 维保风机类型检查得分
     * @return 结果
     */
    public int updateGxtUserFanInspectionScore(GxtUserFanInspectionScore gxtUserFanInspectionScore);

    /**
     * 批量删除维保风机类型检查得分
     * 
     * @param ids 需要删除的维保风机类型检查得分主键集合
     * @return 结果
     */
    public int deleteGxtUserFanInspectionScoreByIds(Long[] ids);

    /**
     * 删除维保风机类型检查得分信息
     * 
     * @param id 维保风机类型检查得分主键
     * @return 结果
     */
    public int deleteGxtUserFanInspectionScoreById(Long id);
}